@@ -2,7 +2,6 @@
 from __future__ import annotations
 
 import logging
-from typing import Dict, Optional
 
 import voluptuous as vol
 
@@ -14,13 +13,13 @@ from homeassistant.const import (
     CONF_MINIMUM,
     CONF_NAME,
 )
-from homeassistant.core import callback
+from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import collection
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.restore_state import RestoreEntity
 from homeassistant.helpers.storage import Store
-from homeassistant.helpers.typing import ConfigType, HomeAssistantType
+from homeassistant.helpers.typing import ConfigType
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -102,7 +101,7 @@ CONFIG_SCHEMA = vol.Schema(
 )
 
 
-async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
+async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Set up the counters."""
     component = EntityComponent(_LOGGER, DOMAIN, hass)
     id_manager = collection.IDManager()
@@ -156,16 +155,16 @@ class CounterStorageCollection(collection.StorageCollection):
     CREATE_SCHEMA = vol.Schema(CREATE_FIELDS)
     UPDATE_SCHEMA = vol.Schema(UPDATE_FIELDS)
 
-    async def _process_create_data(self, data: Dict) -> Dict:
+    async def _process_create_data(self, data: dict) -> dict:
         """Validate the config is valid."""
         return self.CREATE_SCHEMA(data)
 
     @callback
-    def _get_suggested_id(self, info: Dict) -> str:
+    def _get_suggested_id(self, info: dict) -> str:
         """Suggest an ID based on the config."""
         return info[CONF_NAME]
 
-    async def _update_data(self, data: dict, update_data: Dict) -> Dict:
+    async def _update_data(self, data: dict, update_data: dict) -> dict:
         """Return a new updated data object."""
         update_data = self.UPDATE_SCHEMA(update_data)
         return {**data, **update_data}
@@ -174,14 +173,16 @@ class CounterStorageCollection(collection.StorageCollection):
 class Counter(RestoreEntity):
     """Representation of a counter."""
 
-    def __init__(self, config: Dict):
+    _attr_should_poll: bool = False
+
+    def __init__(self, config: dict) -> None:
         """Initialize a counter."""
-        self._config: Dict = config
-        self._state: Optional[int] = config[CONF_INITIAL]
+        self._config: dict = config
+        self._state: int | None = config[CONF_INITIAL]
         self.editable: bool = True
 
     @classmethod
-    def from_yaml(cls, config: Dict) -> Counter:
+    def from_yaml(cls, config: dict) -> Counter:
         """Create counter instance from yaml config."""
         counter = cls(config)
         counter.editable = False
@@ -189,27 +190,22 @@ class Counter(RestoreEntity):
         return counter
 
     @property
-    def should_poll(self) -> bool:
-        """If entity should be polled."""
-        return False
-
-    @property
-    def name(self) -> Optional[str]:
+    def name(self) -> str | None:
         """Return name of the counter."""
         return self._config.get(CONF_NAME)
 
     @property
-    def icon(self) -> Optional[str]:
+    def icon(self) -> str | None:
         """Return the icon to be used for this entity."""
         return self._config.get(CONF_ICON)
 
     @property
-    def state(self) -> Optional[int]:
+    def state(self) -> int | None:
         """Return the current value of the counter."""
         return self._state
 
     @property
-    def state_attributes(self) -> Dict:
+    def extra_state_attributes(self) -> dict:
         """Return the state attributes."""
         ret = {
             ATTR_EDITABLE: self.editable,
@@ -223,7 +219,7 @@ class Counter(RestoreEntity):
         return ret
 
     @property
-    def unique_id(self) -> Optional[str]:
+    def unique_id(self) -> str | None:
         """Return unique id of the entity."""
         return self._config[CONF_ID]
 
@@ -241,14 +237,15 @@ class Counter(RestoreEntity):
         await super().async_added_to_hass()
         # __init__ will set self._state to self._initial, only override
         # if needed.
-        if self._config[CONF_RESTORE]:
-            state = await self.async_get_last_state()
-            if state is not None:
-                self._state = self.compute_next_state(int(state.state))
-                self._config[CONF_INITIAL] = state.attributes.get(ATTR_INITIAL)
-                self._config[CONF_MAXIMUM] = state.attributes.get(ATTR_MAXIMUM)
-                self._config[CONF_MINIMUM] = state.attributes.get(ATTR_MINIMUM)
-                self._config[CONF_STEP] = state.attributes.get(ATTR_STEP)
+        if (
+            self._config[CONF_RESTORE]
+            and (state := await self.async_get_last_state()) is not None
+        ):
+            self._state = self.compute_next_state(int(state.state))
+            self._config[CONF_INITIAL] = state.attributes.get(ATTR_INITIAL)
+            self._config[CONF_MAXIMUM] = state.attributes.get(ATTR_MAXIMUM)
+            self._config[CONF_MINIMUM] = state.attributes.get(ATTR_MINIMUM)
+            self._config[CONF_STEP] = state.attributes.get(ATTR_STEP)
 
     @callback
     def async_decrement(self) -> None:
@@ -276,7 +273,7 @@ class Counter(RestoreEntity):
         self._state = self.compute_next_state(new_state)
         self.async_write_ha_state()
 
-    async def async_update_config(self, config: Dict) -> None:
+    async def async_update_config(self, config: dict) -> None:
         """Change the counter's settings WS CRUD."""
         self._config = config
         self._state = self.compute_next_state(self._state)
