@@ -1,6 +1,8 @@
 """Support for Lagute LW-12 WiFi LED Controller."""
+from __future__ import annotations
 
 import logging
+from typing import Any
 
 import lw12
 import voluptuous as vol
@@ -11,14 +13,15 @@ from homeassistant.components.light import (
     ATTR_HS_COLOR,
     ATTR_TRANSITION,
     PLATFORM_SCHEMA,
-    SUPPORT_BRIGHTNESS,
-    SUPPORT_COLOR,
-    SUPPORT_EFFECT,
-    SUPPORT_TRANSITION,
+    ColorMode,
     LightEntity,
+    LightEntityFeature,
 )
 from homeassistant.const import CONF_HOST, CONF_NAME, CONF_PORT
+from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 import homeassistant.util.color as color_util
 
 _LOGGER = logging.getLogger(__name__)
@@ -36,7 +39,12 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 )
 
 
-def setup_platform(hass, config, add_entities, discovery_info=None):
+def setup_platform(
+    hass: HomeAssistant,
+    config: ConfigType,
+    add_entities: AddEntitiesCallback,
+    discovery_info: DiscoveryInfoType | None = None,
+) -> None:
     """Set up LW-12 WiFi LED Controller platform."""
     # Assign configuration variables.
     name = config.get(CONF_NAME)
@@ -50,6 +58,11 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 class LW12WiFi(LightEntity):
     """LW-12 WiFi LED Controller."""
 
+    _attr_color_mode = ColorMode.HS
+    _attr_should_poll = False
+    _attr_supported_color_modes = {ColorMode.HS}
+    _attr_supported_features = LightEntityFeature.EFFECT | LightEntityFeature.TRANSITION
+
     def __init__(self, name, lw12_light):
         """Initialise LW-12 WiFi LED Controller.
 
@@ -62,10 +75,6 @@ class LW12WiFi(LightEntity):
         self._effect = None
         self._rgb_color = [255, 255, 255]
         self._brightness = 255
-        # Setup feature list
-        self._supported_features = (
-            SUPPORT_BRIGHTNESS | SUPPORT_EFFECT | SUPPORT_COLOR | SUPPORT_TRANSITION
-        )
 
     @property
     def name(self):
@@ -94,11 +103,6 @@ class LW12WiFi(LightEntity):
         """Return true if light is on."""
         return self._state
 
-    @property
-    def supported_features(self):
-        """Return a list of supported features."""
-        return self._supported_features
-
     @property
     def effect_list(self):
         """Return a list of available effects.
@@ -112,11 +116,6 @@ class LW12WiFi(LightEntity):
         """Return True if unable to access real state of the entity."""
         return True
 
-    @property
-    def shoud_poll(self) -> bool:
-        """Return False to not poll the state of this entity."""
-        return False
-
     def turn_on(self, **kwargs):
         """Instruct the light to turn on."""
         self._light.light_on()
@@ -144,7 +143,7 @@ class LW12WiFi(LightEntity):
             self._light.set_light_option(lw12.LW12_LIGHT.FLASH, transition_speed)
         self._state = True
 
-    def turn_off(self, **kwargs):
+    def turn_off(self, **kwargs: Any) -> None:
         """Instruct the light to turn off."""
         self._light.light_off()
         self._state = False
