@@ -1,15 +1,27 @@
 """MySensors notification service."""
-from homeassistant.components import mysensors
-from homeassistant.components.notify import ATTR_TARGET, DOMAIN, BaseNotificationService
+from __future__ import annotations
+
+from typing import Any
+
+from homeassistant.components.notify import ATTR_TARGET, BaseNotificationService
+from homeassistant.const import Platform
+from homeassistant.core import HomeAssistant
+
+from .. import mysensors
+from .const import DevId, DiscoveryInfo
 
 
-async def async_get_service(hass, config, discovery_info=None):
+async def async_get_service(
+    hass: HomeAssistant,
+    config: dict[str, Any],
+    discovery_info: DiscoveryInfo | None = None,
+) -> BaseNotificationService | None:
     """Get the MySensors notification service."""
     if not discovery_info:
         return None
 
     new_devices = mysensors.setup_mysensors_platform(
-        hass, DOMAIN, discovery_info, MySensorsNotificationDevice
+        hass, Platform.NOTIFY, discovery_info, MySensorsNotificationDevice
     )
     if not new_devices:
         return None
@@ -19,7 +31,7 @@ async def async_get_service(hass, config, discovery_info=None):
 class MySensorsNotificationDevice(mysensors.device.MySensorsDevice):
     """Represent a MySensors Notification device."""
 
-    def send_msg(self, msg):
+    def send_msg(self, msg: str) -> None:
         """Send a message."""
         for sub_msg in [msg[i : i + 25] for i in range(0, len(msg), 25)]:
             # Max mysensors payload is 25 bytes.
@@ -27,7 +39,7 @@ class MySensorsNotificationDevice(mysensors.device.MySensorsDevice):
                 self.node_id, self.child_id, self.value_type, sub_msg
             )
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return the representation."""
         return f"<MySensorsNotificationDevice {self.name}>"
 
@@ -35,11 +47,15 @@ class MySensorsNotificationDevice(mysensors.device.MySensorsDevice):
 class MySensorsNotificationService(BaseNotificationService):
     """Implement a MySensors notification service."""
 
-    def __init__(self, hass):
+    def __init__(self, hass: HomeAssistant) -> None:
         """Initialize the service."""
-        self.devices = mysensors.get_mysensors_devices(hass, DOMAIN)
+        self.devices: dict[
+            DevId, MySensorsNotificationDevice
+        ] = mysensors.get_mysensors_devices(
+            hass, Platform.NOTIFY
+        )  # type: ignore[assignment]
 
-    async def async_send_message(self, message="", **kwargs):
+    async def async_send_message(self, message: str = "", **kwargs: Any) -> None:
         """Send a message to a user."""
         target_devices = kwargs.get(ATTR_TARGET)
         devices = [
