@@ -14,7 +14,7 @@ from homeassistant.const import CONF_PORT
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
-from . import SystemBridgeDeviceEntity
+from . import SystemBridgeEntity
 from .const import DOMAIN
 from .coordinator import SystemBridgeDataUpdateCoordinator
 
@@ -72,7 +72,7 @@ async def async_setup_entry(
     async_add_entities(entities)
 
 
-class SystemBridgeBinarySensor(SystemBridgeDeviceEntity, BinarySensorEntity):
+class SystemBridgeBinarySensor(SystemBridgeEntity, BinarySensorEntity):
     """Define a System Bridge binary sensor."""
 
     entity_description: SystemBridgeBinarySensorEntityDescription
