@@ -2,6 +2,9 @@
 import logging
 
 from homeassistant.components.switch import SwitchEntity
+from homeassistant.config_entries import ConfigEntry
+from homeassistant.core import HomeAssistant
+from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from . import XiaomiDevice
 from .const import DOMAIN, GATEWAYS_KEY
@@ -21,7 +24,11 @@ ENERGY_CONSUMED = "energy_consumed"
 IN_USE = "inuse"
 
 
-async def async_setup_entry(hass, config_entry, async_add_entities):
+async def async_setup_entry(
+    hass: HomeAssistant,
+    config_entry: ConfigEntry,
+    async_add_entities: AddEntitiesCallback,
+) -> None:
     """Perform the setup for Xiaomi devices."""
     entities = []
     gateway = hass.data[DOMAIN][GATEWAYS_KEY][config_entry.entry_id]
@@ -37,34 +44,34 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
                     device, "Plug", data_key, True, gateway, config_entry
                 )
             )
-        elif model in [
+        elif model in (
             "ctrl_neutral1",
             "ctrl_neutral1.aq1",
             "switch_b1lacn02",
             "switch.b1lacn02",
-        ]:
+        ):
             entities.append(
                 XiaomiGenericSwitch(
                     device, "Wall Switch", "channel_0", False, gateway, config_entry
                 )
             )
-        elif model in [
+        elif model in (
             "ctrl_ln1",
             "ctrl_ln1.aq1",
             "switch_b1nacn02",
             "switch.b1nacn02",
-        ]:
+        ):
             entities.append(
                 XiaomiGenericSwitch(
                     device, "Wall Switch LN", "channel_0", False, gateway, config_entry
                 )
             )
-        elif model in [
+        elif model in (
             "ctrl_neutral2",
             "ctrl_neutral2.aq1",
             "switch_b2lacn02",
             "switch.b2lacn02",
-        ]:
+        ):
             entities.append(
                 XiaomiGenericSwitch(
                     device,
@@ -85,12 +92,12 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
                     config_entry,
                 )
             )
-        elif model in [
+        elif model in (
             "ctrl_ln2",
             "ctrl_ln2.aq1",
             "switch_b2nacn02",
             "switch.b2nacn02",
-        ]:
+        ):
             entities.append(
                 XiaomiGenericSwitch(
                     device,
@@ -111,7 +118,7 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
                     config_entry,
                 )
             )
-        elif model in ["86plug", "ctrl_86plug", "ctrl_86plug.aq1"]:
+        elif model in ("86plug", "ctrl_86plug", "ctrl_86plug.aq1"):
             if "proto" not in device or int(device["proto"][0:1]) == 1:
                 data_key = "status"
             else:
@@ -142,6 +149,8 @@ class XiaomiGenericSwitch(XiaomiDevice, SwitchEntity):
         self._load_power = None
         self._power_consumed = None
         self._supports_power_consumption = supports_power_consumption
+        # Polling needed for Zigbee plug only.
+        self._attr_should_poll = supports_power_consumption
         super().__init__(device, name, xiaomi_hub, config_entry)
 
     @property
@@ -157,7 +166,7 @@ class XiaomiGenericSwitch(XiaomiDevice, SwitchEntity):
         return self._state
 
     @property
-    def device_state_attributes(self):
+    def extra_state_attributes(self):
         """Return the state attributes."""
         if self._supports_power_consumption:
             attrs = {
@@ -167,14 +176,9 @@ class XiaomiGenericSwitch(XiaomiDevice, SwitchEntity):
             }
         else:
             attrs = {}
-        attrs.update(super().device_state_attributes)
+        attrs.update(super().extra_state_attributes)
         return attrs
 
-    @property
-    def should_poll(self):
-        """Return the polling state. Polling needed for Zigbee plug only."""
-        return self._supports_power_consumption
-
     def turn_on(self, **kwargs):
         """Turn the switch on."""
         if self._write_to_hub(self._sid, **{self._data_key: "on"}):
@@ -194,7 +198,7 @@ class XiaomiGenericSwitch(XiaomiDevice, SwitchEntity):
             if not self._in_use:
                 self._load_power = 0
 
-        for key in [POWER_CONSUMED, ENERGY_CONSUMED]:
+        for key in (POWER_CONSUMED, ENERGY_CONSUMED):
             if key in data:
                 self._power_consumed = round(float(data[key]), 2)
                 break
